@@ -8,12 +8,15 @@
  */
 
 #ifndef __GGV_PREFS_UI_H__
+#define __GGV_PREFS_UI_H__
 
 #include <config.h>
 
 #include <glib.h>
 #include <gconf/gconf-client.h>
 
+#include "ggv-prefs.h"
+
 G_BEGIN_DECLS 
 
 #define GGV_TYPE_PREFS_DIALOG            (ggv_prefs_dialog_get_type ())
@@ -28,27 +31,30 @@ typedef struct _GgvPrefsDialogClass GgvPrefsDialogClass;
 
 struct _GgvPrefsDialog
 {
-        GtkWindow dlg;
+        GtkDialog dlg;
 
         GtkWidget *notebook;
 
-        GtkWidget *gs, *alpha_params, *scan_pdf, *unzip, *unbzip2, *print;   /* entries */
-        GtkWidget *size, *zoom, *orientation, *units;      /* option menus */
-        GtkWidget *watch, *aa, *override_size, *respect_eof, *show_scroll_rect; /* checkbuttons */
+        GtkWidget *gs, *alpha_params, *convert_pdf, *unzip, *unbzip2, *print;   /* entries */
+        GtkWidget *size, *zoom, *orientation, *units, *auto_fit;      /* option menus */
+        GtkWidget *watch, *aa, *override_size, *respect_eof;
+        GtkWidget *show_scroll_rect, *page_flip; /* checkbuttons */
         GtkWidget *override_orientation;
-        GtkWidget *sidebar, *mbar, *sbar, *toolbar, *tblabels, *savegeo,*auto_jump;/* checkbuttons */
+        GtkWidget *sidebar, *mbar, *sbar, *toolbar, *tbstyle[GGV_TOOLBAR_STYLE_LAST], *savegeo,*auto_jump;/* checkbuttons */
         GtkWidget *right_panel;
         GtkWidget **size_choice;               /* paper items */
         GtkWidget **zoom_choice;               /* zoom items */
         GtkWidget **orientation_choice;        /* orientation items */
         GtkWidget **unit_choice;               /* unit items */
+        GtkWidget **auto_fit_choice;           /* auto-fit mode */
+        GtkWidget *scroll_step;
 
         GtkWidget *ok, *cancel, *apply;
 };
 
 struct _GgvPrefsDialogClass
 {
-        GtkWindowClass klass;
+        GtkDialogClass klass;
 };
 
 GType ggv_prefs_dialog_get_type(void);
@@ -57,4 +63,4 @@ void ggv_prefs_dialog_show(GgvPrefsDialog *dlg);
 
 G_END_DECLS
 
-#endif /* __GGV_PREFS_H__ */
+#endif /* __GGV_PREFS_UI_H__ */
