@@ -152,7 +152,6 @@ static gboolean broken_pipe = FALSE;
 
 static void catchPipe(int i)
 {
-        g_message("in catch Pipe!!!\n");
         broken_pipe = True;
 }
 
@@ -546,7 +545,8 @@ gtk_gs_munge_adjustments (GtkGS *gs)
 	 * This is a bit messy:
 	 * we want to make sure that we do the right thing if dragged.
 	 */
-	if (gs->widget.allocation.width >= gs->width) {
+	if (gs->widget.allocation.width >= gs->width ||
+            gs->zoom_mode != GTK_GS_ZOOM_ABSOLUTE) {
 		x = (gs->widget.allocation.width - gs->width)/2;
 		gs->hadj->value = 0.0;
 		gs->hadj->page_size = 1.0;
@@ -562,7 +562,8 @@ gtk_gs_munge_adjustments (GtkGS *gs)
                 gs->hadj->step_increment = 1.0/gs->width;
 		gs->hadj->value = -((gfloat)x)/gs->width;
 	}
-	if (gs->widget.allocation.height >= gs->height) {
+	if (gs->widget.allocation.height >= gs->height ||
+            gs->zoom_mode == GTK_GS_ZOOM_FIT_PAGE) {
 		y = (gs->widget.allocation.height - gs->height)/2;
 		gs->vadj->value = 0.0;
 		gs->vadj->page_size = 1.0;
@@ -681,14 +682,12 @@ gtk_gs_size_allocate (GtkWidget     *widget,
         /* 
          * update the adjustment if necessary (ie. a resize);
          */
-        if (gs->zoom_mode == GTK_GS_ZOOM_ABSOLUTE) {
-                if (GTK_WIDGET_REALIZED(gs)) {
-                        gtk_gs_munge_adjustments (gs);
-                }
-        }
-        else {
+        if (gs->zoom_mode != GTK_GS_ZOOM_ABSOLUTE) {
                 gtk_gs_set_zoom(gs, 0.0);
         }
+        if (GTK_WIDGET_REALIZED(gs)) {
+                gtk_gs_munge_adjustments (gs);
+        }
 
         gtk_gs_goto_page(gs, gs->current_page);
 }
@@ -846,7 +845,7 @@ set_up_page (GtkGS *gs)
         GdkGC *fill;
         GdkColor white = {0, 0xFFFF, 0xFFFF, 0xFFFF}; /* pixel, r, g, b */
 
-#ifdef HAVE_SETLOCALE
+#ifdef HAVE_LOCALE_H
         char *savelocale;
 #endif
 
@@ -894,7 +893,7 @@ set_up_page (GtkGS *gs)
                 }
         }
 
-#ifdef HAVE_SETLOCALE
+#ifdef HAVE_LOCALE_H
         /* gs needs floating point parameters with '.' as decimal point
          * while some (european) locales use ',' instead, so we set the 
          * locale for this snprintf to "C".
@@ -917,7 +916,7 @@ set_up_page (GtkGS *gs)
                    gs->right_margin,
                    gs->top_margin);
 
-#ifdef HAVE_SETLOCALE
+#ifdef HAVE_LOCALE_H
         setlocale (LC_NUMERIC, savelocale);
 #endif
         gdk_property_change(gs->pstarget,
@@ -1414,10 +1413,48 @@ check_pdf (GtkGS *gs)
 		g_free (cmd);
 
 		if ((system (cmdline) == 0)
-		    && ggv_file_readable (filename_dsc)
-		    && (ggv_file_length (filename_err) == 0)) {
+		    && ggv_file_readable (filename_dsc) ) {
+
 			/* success */
 			filename = gs->gs_filename_dsc = filename_dsc;
+			
+			if (ggv_file_length (filename_err) > 0) {
+				gchar *err_msg = " ";
+				GtkWidget *dialog;
+				FILE *err;
+				GdkColor color;
+
+				if ((err = fopen (filename_err, "r"))) {
+
+					/* print the content of the file to a message box */
+					while (fgets (buf, 1024, err))
+						err_msg = g_strconcat (err_msg,buf ,NULL);
+
+					/* FIXME The dialog is not yet set to modal, difficult to 
+					 * get the parent of the dialog box here 
+					 */ 
+
+					dialog = gtk_message_dialog_new (NULL ,
+									 GTK_DIALOG_MODAL,
+									 GTK_MESSAGE_WARNING,
+									 GTK_BUTTONS_OK,
+									 ("There was an error while scaning the file: %s \n%s"),
+									 gs->gs_filename,
+									 err_msg);
+
+					gdk_color_parse ("white", &color);
+					gtk_widget_modify_bg (GTK_WIDGET(dialog), GTK_STATE_NORMAL, &color);
+
+					g_signal_connect (G_OBJECT (dialog), "response",
+							  G_CALLBACK (gtk_widget_destroy),
+							  NULL);
+
+					gtk_window_set_resizable (GTK_WINDOW (dialog), FALSE);
+					gtk_widget_show (dialog);
+					g_free(err_msg);
+				}
+			}
+
 		} else {
 			/* report error */
 			g_snprintf (buf, 1024,
@@ -2157,8 +2194,9 @@ gtk_gs_set_zoom (GtkGS *gs, gfloat zoom) {
                 zoom = ggv_zoom_levels[ggv_max_zoom_levels];
         if (fabs(gs->zoom_factor - zoom) > 0.001) { 
                 gs->zoom_factor = zoom;
-                if (GTK_WIDGET_REALIZED(gs)) 
+                if (GTK_WIDGET_REALIZED(gs)) {
                         set_up_page(gs);
+                }
                 gs->changed = TRUE;
                 gtk_widget_queue_resize (&(gs->widget));
         }
@@ -2181,7 +2219,7 @@ gtk_gs_zoom_to_fit(GtkGS *gs, gboolean fit_width)
 
         g_return_val_if_fail(gs != NULL, 0.0);
         g_return_val_if_fail(GTK_IS_GS(gs), 0.0);
-        
+
 	new_zoom = (gfloat)gs->widget.allocation.width/(gfloat)gs->width*gs->zoom_factor;
 	if(!fit_width) {
 		new_y = new_zoom*gs->height/gs->zoom_factor;
